import React from 'react';
import { Row, Col, Table, Badge, Empty, Tooltip } from "antd";
import { TeamOutlined, InfoCircleOutlined } from "@ant-design/icons";
import DashboardCard from "../../../components/presentation/dashboard-card";
import { theme } from "antd";

interface DeptData {
  id: string;
  name: string;
  count: number;
}

interface DepartmentTableProps {
  filteredDeptData: DeptData[];
  staffs: any[] | undefined;
}

export default function DepartmentTable({ 
  filteredDeptData, 
  staffs 
}: DepartmentTableProps): React.ReactElement {
  const { token } = theme.useToken();

  const deptColumns = [
    {
      title: "部门名称",
      dataIndex: "name",
      key: "name",
    },
    {
      title: "人员数量",
      dataIndex: "count",
      key: "count",
      render: (count: number) => (
        <Badge
          count={count}
          overflowCount={999}
          style={{ backgroundColor: token.colorPrimary }}
        />
      ),
    },
    {
      title: "占比",
      dataIndex: "count",
      key: "percentage",
      render: (count: number) => (
        <span>
          {staffs && staffs.length > 0
            ? ((count / staffs.length) * 100).toFixed(1) + "%"
            : "0%"}
        </span>
      ),
    },
  ];

  return (
    <Row className="mt-4">
      <Col span={24}>
        <DashboardCard
          title={
            <div className="flex items-center justify-between w-full">
              <div>
                <TeamOutlined className="mr-2" />
                <span>部门人员分布详情</span>
              </div>
              <Tooltip title="点击饼图可筛选特定部门数据">
                <InfoCircleOutlined className="text-gray-400" />
              </Tooltip>
            </div>
          }
          className="min-h-80"
        >
          {filteredDeptData.length > 0 ? (
            <Table
              dataSource={filteredDeptData}
              columns={deptColumns}
              rowKey="id"
              pagination={{
                pageSize: 10,
                showTotal: (total) => `共 ${total} 个部门`,
              }}
              size="small"
              className="mt-2"
            />
          ) : (
            <Empty description="暂无部门数据" className="my-8" />
          )}
        </DashboardCard>
      </Col>
    </Row>
  );
}