import { EChartsOption } from "echarts-for-react";

interface DeptData {
  name: string;
  count: number;
  id: string;
}
// 图表配置函数
export const getPieChartOptions = (
  deptData: DeptData[],
  onEvents?: Record<string, (params: any) => void>
): EChartsOption => {
  const top10Depts = deptData.slice(0, 10);
  return {
    tooltip: {
      trigger: "item",
      formatter: "{a} <br/>{b}: {c}人 ({d}%)",
    },
    legend: {
      orient: "vertical",
      right: 10,
      top: "center",
      data: top10Depts.map((dept) => dept.name),
    },
    series: [
      {
        name: "部门人数",
        type: "pie",
        radius: ["50%", "70%"],
        avoidLabelOverlap: false,
        itemStyle: {
          borderRadius: 10,
          borderColor: "#fff",
          borderWidth: 2,
        },
        label: {
          show: true,
          formatter: "{b}: {c}人 ({d}%)",
          position: "outside",
        },
        emphasis: {
          label: {
            show: true,
            fontSize: "18",
            fontWeight: "bold",
          },
        },
        labelLine: {
          show: true,
        },
        data: top10Depts.map((dept) => ({
          value: dept.count,
          name: dept.name,
        })),
      },
    ],
  };
};

export const getBarChartOptions = (deptData: DeptData[]): EChartsOption => {
  const top10Depts = deptData.slice(0, 10);
  return {
    tooltip: {
      trigger: "axis",
      axisPointer: {
        type: "shadow",
      },
    },
    grid: {
      left: "3%",
      right: "12%",
      bottom: "3%",
      containLabel: true,
    },
    xAxis: {
      type: "value",
      boundaryGap: [0, 0.01],
    },
    yAxis: {
      type: "category",
      data: top10Depts.map((dept) => dept.name),
      inverse: true,
    },
    series: [
      {
        name: "人员数量",
        type: "bar",
        data: top10Depts.map((dept) => dept.count),
        itemStyle: {
          color: function (params) {
            const colorList = [
              "#91cc75",
              "#5470c6",
              "#ee6666",
              "#73c0de",
              "#3ba272",
              "#fc8452",
              "#9a60b4",
            ];
            return colorList[params.dataIndex % colorList.length];
          },
        },
        label: {
          show: true,
          position: "right",
          formatter: "{c}人",
        },
      },
    ],
  };
};
